#
# spec file for package kdiff3
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.0.0
%define qt6_version 6.6.0

%bcond_without released
Name:           kdiff3
Version:        1.12.1
Release:        1.2
Summary:        Code Comparison Utility
License:        GPL-2.0-or-later
URL:            https://apps.kde.org/kdiff3
Source0:        https://download.kde.org/stable/%{name}/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/%{name}/%{name}-%{version}.tar.xz.sig
Source2:        kdiff3.keyring
%endif
BuildRequires:  cmake >= 3.22
BuildRequires:  boost-devel >= 1.82
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6PrintSupport) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  pkgconfig(icu-i18n) >= 70.0
BuildRequires:  pkgconfig(icu-uc) >= 70.0

%description
KDiff3 is a program that:

* Compares or merges two or three text input files or directories
* Shows the differences line-by-line and character-by-character
* Provides an automatic merge facility and an integrated editor for
  solving merge conflicts
* Supports KDE's KIO framework (allows accessing ftp, sftp, fish, smb, etc.)

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name --with-man --with-html

%fdupes %{buildroot}

%files
%license LICENSES/*
%doc %lang(en) %{_kf6_htmldir}/en/kdiff3/
%doc %lang(en) %{_kf6_mandir}/man1/kdiff3.1%{?ext_man}
%{_kf6_applicationsdir}/org.kde.kdiff3.desktop
%{_kf6_appstreamdir}/org.kde.kdiff3.appdata.xml
%{_kf6_bindir}/kdiff3
%{_kf6_iconsdir}/hicolor/*/apps/kdiff3.png
%{_kf6_iconsdir}/hicolor/scalable/apps/kdiff3.svgz
%dir %{_kf6_plugindir}/kf6/kfileitemaction
%{_kf6_plugindir}/kf6/kfileitemaction/kdiff3fileitemaction.so

%files lang -f %{name}.lang
%exclude %{_kf6_htmldir}/en/kdiff3

%changelog
* Sat Feb 22 2025 Christophe Marin <christophe@krop.fr>
- Update to 1.12.1
  * fixed horizontal scroll with track pad ignored.
  * reduce initial file load time
  * ignore encoding errors during merge this will become a warning.
  * adjust flatpak default flags.
  * drop unused Qt6Core5Compat depenancy check.
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.12.0
  * Completed port away from Qt5, 6.6 now required version due
    to delayed ICU support in Qt
  * Fixed UTF-8-BOM output encoding issues mustly seen on windows.
  * horizontal scroll correctly comptuted for diff windows
  * False errors on first launch with files selected should be fixed.
    (kde#497102, boo#1234260)
* Wed Nov 20 2024 Christophe Marin <christophe@krop.fr>
- Stop using the %%suse_update_desktop_file macro
* Fri Nov  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.11.5
  * Fix false memory error when using "admin://" protocol
  * Cleanup BOM handling lock detection to only known UTF-*
    encodings that use it.
  * Fix bugged connection to non-existent signal (This is why
    we now use new style connections only.)
  * fix regression in diff margin color.
  * fix crash on deleting first line in diff block
  * fix merge encoding detection.
* Tue Oct  1 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.11.4
  * Adapt Diff3Line::getLineData to handle being called on
    non-existant lines
  * Suppress clang warning for quirky QT "enum" use
  * Pass over diff code completely if no data is loaded
  * Do full clearing of all diff related lists when one is cleared
* Mon Jul  1 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.11.2
  * Fixed encoding handling for non-UTF encodings
  * Fixed encoding detection for lower case 'HTML' and 'XML' tags
* Tue May 21 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.11.1.
  * kparts is no longer needed
  * Don't set invalid first line if line < visableLines
  * Actually wait for event loop to exit in
    ProgressDialog::enterEventLoop
  * Don't kill KJob on hide
  * Cleanup resize code
  * Limit new line computation to 0
  * Fix broken getBestFirstLine calcucation
- Drop obsolete patch:
  * Fix-linking-with-boost-1.75.0.patch
* Thu Jan 25 2024 Wolfgang Bauer <wbauer1@a1.net>
- Update to 1.10.7
  * Correctly handle oversized files (kde#475176)
* Thu Oct  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 1.10.6
  * Fix crash on exit
* Wed Jul 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 1.10.5:
  * Resolve thread safety issues in word wrap runner
* Fri Jun  9 2023 Adam Spiers <suse@adamspiers.org>
- Update to 1.10.4
  * Fixed no UI shown for failed auto-merge.
- Update to 1.10.3
  * Fix 469817 no text if word wrap is on.
* Wed May  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 1.10.2
  * Prevent false error due to faulty check when
    m_pOptions->m_bDiff3AlignBC = true
  * fix crash when word wrap enabled (kde#468492)
  * Rework KDiff3App::completeInit to avoid crash on exit in auto
    mode
  * "Escape" shortcut ignored if merge output in focus (kde#467652)
  * save and restore dock states (kde#466522)
  * Show UI before comparison start (kde#439148)
  * Don't crash on broken links (kde#466241)
  * Fix memory safety issues during reload. (kde#466524)
  * Fix mishandling line count for files containing '0x0b'
* Tue Jan 17 2023 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.10.0
  * Make DirectoryMergeWindow and DirectoryMergeInfo QDockWidgets
  * Use Qt native saveState/restoreState
- Build with boost 1.75.0 on Leap as the standard version is too
  old (kdiff3 requires at least 1.71 now)
- Add Fix-linking-with-boost-1.75.0.patch to workaround a bug in
  boost 1.75.0 that breaks the linking stage
* Wed Dec  7 2022 Dirk Müller <dmueller@suse.com>
- update to 1.9.6:
  * Fix horizontal scroll to be by character not pixels
  * Update window when ending selection mode.
* Fri Mar  4 2022 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.9.5
  * Attempt encoding detection for non-BOM UTF-8
  * Rewrite EOL detection (kde#448353,kde#450225)
    + fixes speed regression
    + Better EOL detection decoding handled by Qt
- Drop redundant recommendation of the -lang package
* Tue Nov 23 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.9.4
  * Fix windows style cr/lf line ending handling (kde#442199)
  * Fix race on exit if qt sends QApplication::focusChanged during
    teardown (kde#444654)
* Fri Aug 20 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.9.3
  * Fix multiple regressions in file comparison
  * Fix trailing EOL stripped (kde#437570)
  * Fix arbitrary line insertion during merge (kde#437570)
- Drop 0001-Collected-fixes-from-master.patch, the relevant fixes
  are included in this release
* Mon Jun 28 2021 Tilman Vogel <tilman.vogel@web.de>
- Remove GCC 11 build fix:
  * 0001-Explicitly-include-limits-for-compatibility-with-gcc.patch
    now contained in squashed patch
- Add collected fixes from upstream master:
  * 0001-Collected-fixes-from-master.patch
    contains the original and many more fixes:
    + misalignment and wrong conflict resolutions when using manual
    alignment markers
    + uninitialized variables causing crashes
    + hangs and crashes due to wrong loop conditions
    + wrong handling of new-line at end-of-file
    + spurious insertion of empty lines in merge result
    + access of uninitialized iterators causing crashes
    + wrong buffer length calculations causing out-of-bounds access
    + wrong bit-logic causing comments to always be treated as white-space
    + crashes when hitting a key on empty merge results
    + technical details allowing fixes to be cherry-picked
* Fri May 28 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add GCC 11 build fix:
  * 0001-Explicitly-include-limits-for-compatibility-with-gcc.patch
- Drop the _service file. Upstream release doesn't contain
  precompiled code anymore.
* Mon May 17 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.9.2
  * Remove erroneous #ifdef (kde#436958)
* Sat May 15 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.9.1
  * Hotfix for possible display problems (kde#436958)
  * Add default shortcut for "Go to [Previous/Next] Unsolved
    Conflict" (kde#436003)
  * Port away from KIconThemes
* Wed May  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update URL.
* Mon May  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.9.0
  * Rewrite of SourceData::FileData::preprocess now only loops
    through file contents once.
  * Major rework of event handling
  * Take advantage of Qt and boost signal/slot pattern to avoid
    needless nullptr checks.
  * Introduce LineRef wrapper class
  * Add enum types and use existing ones.
  * Split out doDirectoryCompare from improveFilenames
  * Stop mis-using c style [] pointer access
* Fri Mar  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Use a _service file to exclude the windows_installer folder.
* Fri Jan 22 2021 wbauer@tmo.at
- Update to 1.8.5:
  * Fix url handling for drag and drop (kde#417189)
  * Fix regression in handling paste from clipboard to blank diff
    window (kde#426823)
  * Fix link detection via KIO
  * Drop custom event filter in OpenDialog. We now use
    FileNameLineEdit instead as in the main window.
  * Fix url/path handling bugs for remote files
  * Don't ignore stat errors unless it tells us the file was not
    found
* Thu Sep  3 2020 wbauer@tmo.at
- Update to 1.8.4:
  * Fix typos in man page (kde#424177)
  * Fix compare over network with KIO (kde#408119)
  * Restore contextmenu for Windows Explorer
* Thu Aug 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Spec cleanup
* Thu Jun 25 2020 wbauer@tmo.at
- Update to 1.8.3:
  * Fixed reload on Windows (kde#423001)
  * Fixed error handling during directory compare
  * Only give one error message per directory compare operation
  * Fix crash when clipboard is not available (kde#419722)
  * Rework initial window display and full screen toggling
  * Treat /dev/null as non-existant as git expects (kde#421048)
* Mon Mar 30 2020 wbauer@tmo.at
- Update to 1.8.2:
  * Allowing editing of blank lines and don't mark newly inserted
    lines as a conflict (kde#411472)
  * Remove broken attempt to optimize drawing on horizontal scroll
  * Fix line numbers not shown. Use QString::number directly not
    through a format string. (kde#418813)
  * Correctly support "Print Current Page"
  * Don't attempt to free nullptr in SourceData::FileData::reset()
  * Make Preference dialog panes scroll-able if too large to fit on
    screen
  * Fix dialog filter on windows
  * Switch to QElapsedTime for timing avoids explicitly undefined
    behavior inside qt if time is changed
  * Fix sync mode
  * Make matching in CvsIngnoreList always honor bCaseSensitive
    setting
  * Don't use temporary with QLatin1String constructor, strange
    things will happen
  * ignore oversized cvsignore files
  * Fix '-L' parameter handling (kde#410962)
  * Restore accidentally deleted --auto option
  * Fixing missing menu items (kde#411602), also resolves a
    potential crash in MergeResultWindow::slotUpdateAvailabilities
    (kde#407745)
  * Prevent intermittent crash during reload/refresh
  * Show diff for empty/missing files (kde#410008)
  * Don't give false error when comparing empty folders
  * Close files when not in use - Fixes "Too many open files" bug
    (kde#408991)
  * Avoid crash when receiving mouse or key events during early
    startup (kde#407829)
  * Don't try to manually build url if parent is not set
  * Fix crash when canceling by using only one event loop in
    ProgressDialog
  * Don't append to already complete url
  * Fix manual url building in FileAccess::setFromUdsEntry -
    scheme should not change now
  * Fix craft install instructions for windows (kde#405918)
  * Fix crash in OptionDialog::slotApply() (kde#411586)
  * Fix crash in MergeResultWindow::slotUpdateAvailabilities
    (kde#407745)
  * Fixed redraw for horizontal scrolling (kde#407894, kde#399070)
* Sun May 19 2019 wbauer@tmo.at
- Update to 1.8.1:
  * Fix enabling of delta movement (kde#407562)
* Tue May 14 2019 wbauer@tmo.at
- Update to 1.8:
  * Ported to Qt5/KDE Frameworks 5
  * Bugfix: Show Identical files setting not applied after rescan
  * Change parameter errors to use dialog on Linux as well as
    console output
  * Don't sort twice when sorting in reverse order
  * Fix memory leak introduced in 0.9.91
  * Implement Cut/Paste
  * Don't enable "Choose C for Everything" on two way merge
  * Cleanup code
- Update package summary and description
- Run spec-cleaner
* Thu Dec  8 2016 fabian@ritter-vogt.de
- Revert kde4_runtime_requires change
* Tue Nov 29 2016 olaf@aepfle.de
- Expand macro kde4_runtime_requires only when its available
  to fix quilt setup
* Wed Jun 24 2015 wbauer@tmo.at
- update to 0.9.98:
  * Text rendering now with QTextLayout fixes the following issues
    + Correct handling for variable width fonts.
    + Corrected display of highlighted text with Qt4.8.x on Ubuntu and Mac.
    + Improved handling of texts with both right to left and left to right languages (mixed Arabic and western texts).
    + Improved handling of Chinese and Japanese.
    + Whitespace characters are now shown as dots for spaces and arrows for tabs, and not only in differences.
  * Bugfixes.
- removed kdiff3-fix-save-relative-path.patch (included upstream)
* Fri Jul 26 2013 hrvoje.senjan@gmail.com
- BuildRequire only libkde4-devel, instead of kdebase4-workspace-devel
* Thu May  2 2013 aspiers@suse.com
- Add kdiff3-fix-save-relative-path.patch: fix saving merged
  files.  Patch is from: https://bugs.archlinux.org/task/31813
  and is already upstream.
* Tue Nov 20 2012 nico.kruber@gmail.com
- Fix the SLES build (%%make_install is not expanded on SLES)
* Tue Nov 20 2012 nico.kruber@gmail.com
- update to 0.9.97:
  * Memory usage optimized for comparison of large directories.
  * In overview for two way diff show if only one side contains text.
  * If text is selected in either input or output window use that in Find dialog.
  * Command line option --cs doesn't change the config value permanently anymore.
  * Windows 64 bit specific installer.
  * Bugfixes.
- removed libkdiff3part.so (not build anymore)
* Tue Oct 11 2011 dmueller@suse.de
- update to 0.9.96:
  * KDiff3FileItemActionPlugin : Context menu that also works in dolphin (for KDE>=4
  * Parser for preprocessor commands. (Allows single apostrophs ')
  * Fix crash on A/B-overview (infinite recursion)
  * Fix clearcase temp files not deleted problem on windows
  * KDiff3 plugin: When launching KDiff3 konqueror isn't blocked anymore
  * String corrections (Frederik Schwarzer)
  * Fixed writing to KIO.
  * Fixed white space merge default options
* Sat Sep 17 2011 toddrme2178@gmail.com
- Removed checks for obsolete openSUSE versions (fix for RPMLINT warnings)
- Added check for duplicate files (fix for RPMLINT warning)
- Cleaned up spec file formatting
* Tue Aug 10 2010 beineri@opensuse.org
- updated tarball to fix build
* Mon Mar  8 2010 coolo@novell.com
- do not package docs in both subpackages
* Wed May 20 2009 beineri@opensuse.org
- require kdiff3-lang
* Fri Mar  6 2009 wstephenson@suse.de
- update to 0.9.95:
  * Show line end style for each file
  * Translation update
  * Bugfixes
* Fri Feb 20 2009 dmueller@suse.de
- update to 0.9.94:
  * ported to KDE4
  * various smaller fixes
* Sat Feb 14 2009 coolo@suse.de
- call kde_post_install
* Mon Nov 17 2008 stbinner@suse.de
- install translations for kdiff3 menu plugin (bnc#442527)
* Wed Jun 13 2007 stbinner@suse.de
- running fdupes makes kdiff3.rpm 348KB smaller
* Sun Apr 15 2007 stbinner@suse.de
- update to version 0.9.92:
  * KDE-Konqueror plugin: Launch KDiff3 from Konqueror.
  * Temp file names use process id in file name for several instances.
  * New File comparison mode: Trust the size and date, but use
    binary comparison if date doesn't match (unsafe)
  * Open dialog also shows current dirs in directory comparison mode.
  * New option for history merge: Max number of history entries
  * New option "Auto save and quit on merge without conflicts"
  * Several Bugfixes
* Sun Nov  5 2006 stbinner@suse.de
- update to version 0.9.91:
  * Unicode autodetection based on byte-order-mark.
  * Fix for crash after double click below last line
  * Saving of maximized window-state (Patch by Robert Vock)
  * Separated Merge-options in own tab
  * When pasting multiple lines into openfile dialog only first
    line is kept
  * Drawing in directory view fixed.
  * When specifying a separate output dir then for equal files a
    copy operation will also be offered.
* Wed May 24 2006 adrian@suse.de
- fix build for < 10.1
* Tue May 16 2006 stbinner@suse.de
- update to version 0.9.90
  * Fixed KIO-problems of type "File exists" with tempfiles.
  * Fix for manual alignment with 3 files which caused crash.
  * Preserve executable bit when overwriting an existing file.
  * Documentation and translations updated.
* Mon Apr 10 2006 stbinner@suse.de
- update to version 0.9.89
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Oct 25 2005 stbinner@suse.de
- update to version 0.9.88 (unicode support)
* Thu Feb 17 2005 adrian@suse.de
- menu entry moved to xdg dir
* Sat Sep  4 2004 coolo@suse.de
- fixing Makefile problems
* Sat Aug 28 2004 adrian@suse.de
- initial package of version 0.9.86
